"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const client_dynamodb_1 = require("@aws-sdk/client-dynamodb");
const luxon_1 = require("luxon");
/*
-- uncomment this block for development and debug
console.log(process.env.AWS_REGION)
console.log(process.env.DYNAMODB_CREDENTIAL_TABLE)
getCredential(process.env.AWS_REGION, process.env.DYNAMODB_CREDENTIAL_TABLE, 'xxxx-xxxx-xxxxx')
*/
function getCredential({ awsRegion, dynamodbTable, key }) {
    return __awaiter(this, void 0, void 0, function* () {
        const client = new client_dynamodb_1.DynamoDBClient({ region: awsRegion });
        const getItemCommandInput = {
            TableName: dynamodbTable,
            Key: {
                key: { S: key }
            },
            AttributesToGet: ['enabled', 'credential', 'usageCounter']
        };
        const response = yield client.send(new client_dynamodb_1.GetItemCommand(getItemCommandInput));
        if (response.Item) {
            if (response.Item.enabled && response.Item.enabled.BOOL) {
                // Item is enabled, update the lastAccessedAt, lastUsedAt and usageCounter values
                const credential = response.Item.credential.S;
                // Prepend the string with '+' to cast it to a number
                const usageCounter = +response.Item.usageCounter.N;
                const updateItemCommandInput = {
                    TableName: dynamodbTable,
                    Key: {
                        key: {
                            S: key
                        }
                    },
                    UpdateExpression: 'SET lastAccessedAt = :val1, lastUsedAt = :val1, usageCounter=:val2',
                    ExpressionAttributeValues: {
                        ':val1': { S: luxon_1.DateTime.now().toISO() },
                        ':val2': { N: `${usageCounter + 1}` }
                    }
                };
                try {
                    yield client.send(new client_dynamodb_1.UpdateItemCommand(updateItemCommandInput));
                    // Return the credential string
                    return credential;
                }
                catch (error) {
                    return null;
                }
            }
            else {
                // Item is disabled, update the lastAccessedAt value
                const updateItemCommandInput = {
                    TableName: dynamodbTable,
                    Key: {
                        key: { S: key }
                    },
                    UpdateExpression: 'SET lastAccessedAt = :val1',
                    ExpressionAttributeValues: {
                        ':val1': { S: luxon_1.DateTime.now().toISO() }
                    }
                };
                try {
                    yield client.send(new client_dynamodb_1.UpdateItemCommand(updateItemCommandInput));
                    // Return the credential string
                    return null;
                }
                catch (error) {
                    return null;
                }
            }
        }
    });
}
exports.default = getCredential;
