"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const client_dynamodb_1 = require("@aws-sdk/client-dynamodb");
const luxon_1 = require("luxon");
/*
-- uncomment this block for development and debug
console.log(process.env.AWS_REGION)
console.log(process.env.DYNAMODB_CREDENTIAL_TABLE)
getCredential(process.env.AWS_REGION, process.env.DYNAMODB_CREDENTIAL_TABLE, 'xxxx-xxxx-xxxxx')
*/
async function getCredential({ awsRegion, dynamodbTable, key }) {
    const client = new client_dynamodb_1.DynamoDBClient({ region: awsRegion });
    const getItemCommandInput = {
        TableName: dynamodbTable,
        Key: {
            key: { S: key }
        },
        AttributesToGet: ['enabled', 'credential', 'usageCounter']
    };
    const response = await client.send(new client_dynamodb_1.GetItemCommand(getItemCommandInput));
    if (response.Item) {
        if (response.Item.enabled && response.Item.enabled.BOOL) {
            // Item is enabled, update the lastAccessedAt, lastUsedAt and usageCounter values
            const credential = response.Item.credential.S;
            // Prepend the string with '+' to cast it to a number
            const usageCounter = +response.Item.usageCounter.N;
            const updateItemCommandInput = {
                TableName: dynamodbTable,
                Key: {
                    key: {
                        S: key
                    }
                },
                UpdateExpression: 'SET lastAccessedAt = :val1, lastUsedAt = :val1, usageCounter=:val2',
                ExpressionAttributeValues: {
                    ':val1': { S: luxon_1.DateTime.now().toISO() },
                    ':val2': { N: `${usageCounter + 1}` }
                }
            };
            try {
                await client.send(new client_dynamodb_1.UpdateItemCommand(updateItemCommandInput));
                // Return the credential string
                return credential;
            }
            catch (error) {
                return null;
            }
        }
        else {
            // Item is disabled, update the lastAccessedAt value
            const updateItemCommandInput = {
                TableName: dynamodbTable,
                Key: {
                    key: { S: key }
                },
                UpdateExpression: 'SET lastAccessedAt = :val1',
                ExpressionAttributeValues: {
                    ':val1': { S: luxon_1.DateTime.now().toISO() }
                }
            };
            try {
                await client.send(new client_dynamodb_1.UpdateItemCommand(updateItemCommandInput));
                // Return the credential string
                return null;
            }
            catch (error) {
                return null;
            }
        }
    }
}
exports.default = getCredential;
